#
# spec file for package python-pytest-subtests
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-subtests
Version:        0.14.1
Release:        2.1
Summary:        Python unittest subTest() support and subtests fixture
License:        MIT
URL:            https://github.com/pytest-dev/pytest-subtests
Source:         https://files.pythonhosted.org/packages/source/p/pytest-subtests/pytest_subtests-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs >= 19.2.0
Requires:       python-pytest >= 7.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module attrs >= 19.2.0}
BuildRequires:  %{python_module pytest >= 7.0}
# /SECTION
%python_subpackages

%description
Python unittest subTest() support and subtests fixture.

%prep
%setup -q -n pytest_subtests-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE
%{python_sitelib}/pytest_subtests
%{python_sitelib}/pytest_subtests-%{version}.dist-info

%changelog
* Tue Apr 22 2025 Markéta Machová <mmachova@suse.com>
- pytest made attrs optional, add it here
* Fri Jan 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.14.1:
  * Fix self.instance._outcome is None case in #173 (#174).
- update to 0.14.0:
  * Add support for Python 3.13.
  * Dropped support for EOL Python 3.8.
  * Fixed output when using TestCase.skipTest (#169).
  * Fixed pytest requirement to >=7.3 (#159).
- update to 0.13.1:
  * Fixed bug were an extra test would execute when -x/--exitfirst
    was used (#139).
- update to 0.13.0:
  * Dropped support for EOL Python 3.7.
  * Added support for -x/--exitfirst (#134).
  * Hide the traceback inside the SubTests.test() method (#131).
* Mon Mar 25 2024 Dirk Müller <dmueller@suse.com>
- update to 0.12.1:
  * Fixed compatibility with upcoming pytest 8.1.x.  (#125).
  * Python 3.12 is now officially supported (#113).
  * Added typing support (#115).
  * SubTests can be imported from pytest_subtests to type-
    annotate the subtests fixture.
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 0.11.0:
  * Logging is displayed for failing subtests (`#92`_)
  * Passing subtests no longer turn the pytest output to yellow
    (as if warnings have been issued)
  * Now the ``msg`` contents of a subtest is displayed when
    running pytest with ``-v``.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Mon Mar 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.10.0:
  * Added experimental support for suppressing subtest output
    dots in non-verbose mode with ``--no-subtests-shortletter``
  - - this allows the native pytest column calculations to not
    be disrupted and minimizes unneeded output for large CI
    systems.
* Tue Jan 10 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.9.0:
  * Python 3.11 is officially supported.
  * Dropped support for Python 3.6.
  * Now passing subtests are shown in the test run summary at the end (for
    example: 10 failed, 1 passed, 10 subtests passed in 0.10s) (#70).
  * Fixed support for pytest 7.0, and pytest>=7.0 is now required.
  * pytest>=6.0 is now required.
  * Added official support for Python 3.10.
  * Dropped support for Python 3.5.
  * Users no longer need to configure a warnings filter for the internal A
    private pytest class or function was used pytest warning (#52).
  * Experimental: Use SUBPASS and , for passed subtests instead of general
    PASSED, SUBFAIL and u for failed ones instead of FAILED (#30).
* Thu Oct  7 2021 Pedro Monreal <pmonreal@suse.com>
- Update to 0.5.0
  * Add support for pytest.mark.xfail
* Sat Mar 20 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.4.0
  * Add Python 3.9 support and bump pytest requirement
  * Add support for --pdb
* Thu Nov  5 2020 Marketa Machova <mmachova@suse.com>
- Update to 0.3.2
  * Fix pytest 6.0 support.
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.1:
  * Fix pytest 5.4 support.
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.0:
  * subtests now correctly captures and displays stdout/stderr (#18).
* Wed Aug 28 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.2.1
